<div align="center">
  <br>
  <img src="/docs/_static/asteca_icon.webp" alt="UCC" width="200"/>
  <br>
</div>


# ASteCA [Automated Stellar Cluster Analysis]
[![AA](https://img.shields.io/badge/A%26A-576--A6,%202015-yellowgreen.svg)][1]
[![License](https://img.shields.io/badge/license-MIT-blue)][2]

**ASteCA** is a package designed to automatize the usual analysis applied on star
clusters, in order to estimate their characteristics and fundamental parameters.

Install with:

```
pip install asteca
```

See the [documentation](https://asteca.github.io) for more details. If you use this
package in your research, please cite its accompanying [article][1] using the following
Bibtex:

````
@article{Perren_2015,
    author = {{Perren, G. I.} and {V\'azquez, R. A.} and {Piatti, A. E.}},
    title = {ASteCA: Automated Stellar Cluster Analysis},
    DOI= "10.1051/0004-6361/201424946",
    url= "http://dx.doi.org/10.1051/0004-6361/201424946",
    journal = {A\&A},
    year = 2015,
    volume = 576,
    pages = "A6",
    month = "04",
}
````

[1]: http://www.aanda.org/articles/aa/abs/2015/04/aa24946-14/aa24946-14.html
[2]: https://opensource.org/license/mit/
[3]: http://asteca.github.io
[4]: https://github.com/asteca/asteca/releases/latest


